require 'colorize'

module EventModule
  
  module InstanceMethods
    
    def event_sequence
      make_events
      show_event_list
      select_event
      view_another_event
    end
    
    def make_events
      array = Scraper.scrape_events
      Event.create(array.uniq)
    end
    
    def show_event_list
      Event.all.each.with_index(1) do |event, index|
        puts "\n------ ".colorize(:light_magenta)+"#{index}.".colorize(:light_blue)+" #{event.title.upcase}".colorize(:light_magenta)
        puts "------ #{event.date}"
        puts "------ #{event.time}"
      end
      puts "\nAbove is a list of upcoming events for women and girls studying STEM subjects in the UK.\nEnter a number between "+"1-#{Event.all.length}".colorize(:light_blue)+" to see more information:\n"
    end

    def select_event
      input = gets.strip
      if input.to_i.between?(1,Event.all.length)
        event = Event.find(input.to_i)
        show_event(event)
      elsif input.downcase == "exit" || input == "q" || input == "quit"
        exit
      else
        puts error.colorize(:light_blue)
        show_event_list
        select_event
        view_another_event
      end
    end
    
    def show_event(event)
      puts "\n\n----------- #{event.title.upcase} -----------".colorize(:light_magenta)
      puts "\n\n#{event.date}".colorize(:light_blue)
      puts "\n#{event.time}".colorize(:light_blue)
      puts "\n#{event.website}".colorize(:light_blue)
      puts "\n\n#{event.description}\n\n".colorize(:light_magenta)
    end
    
    def view_another_event
      puts "\nWould you like to view another event?"
      puts prompt.colorize(:light_blue)
      input = gets.strip.downcase
      if input == "y"
        show_event_list
        select_event
        view_another_event
      elsif input == "n"
        view_scholarships_after_events
      else
        puts error.colorize(:light_blue)
        view_another_event
      end
    end
    
    def view_scholarships_after_events
      puts "\nWould you like to view funding options?"
      puts prompt.colorize(:light_blue)
      input = gets.strip.downcase
      if input == "y"
        reset_scholarships
        scholarship_sequence
      elsif input == "n"
        puts goodbye.colorize(:light_blue)
        exit
      else
        puts error.colorize(:light_blue)
        view_scholarships_after_events
      end
    end
    
    def reset_scholarships
      Scholarship.reset_all
    end
  
  end
  
  module ClassMethods
  end
  
end