module FundingModule
  
  module InstanceMethods
    
    def scholarship_sequence
      make_scholarships
      show_scholarship_list
      select_scholarship
      view_another_scholarship
    end
    
    def make_scholarships
      array = Scraper.scrape_scholarships
      Scholarship.create(array.uniq)
    end
    
    def show_scholarship_list
      Scholarship.all.each.with_index(1) do |scholarship, index|
        puts "----------- ".colorize(:light_magenta)+"#{index}.".colorize(:light_blue)+"#{scholarship.title.upcase}".colorize(:light_magenta)
      end
      puts "\nAbove is a list of organisations offering funding, bursaries, grants, awards and scholarships for women and girls studying STEM subjects in the UK.\nEnter a number between "+"1-#{Scholarship.all.length}".colorize(:light_blue)+" to see more information:\n"
    end

    def select_scholarship
      input = gets.strip
      if input.to_i.between?(1,Scholarship.all.length)
        scholarship = Scholarship.find(input.to_i)
        show_scholarship(scholarship)
      elsif input.downcase == "exit" || input == "q" || input == "quit"
        exit
      else
        puts error.colorize(:light_blue)
        show_scholarship_list
        select_scholarship
        view_another_scholarship
      end
    end
    
    def show_scholarship(scholarship)
      puts "\n\n----------- #{scholarship.title.upcase} -----------".colorize(:light_magenta)
      puts "\n#{scholarship.website}".colorize(:light_blue)
      puts "\n\n#{scholarship.description}\n\n".colorize(:light_magenta)
    end
    
    def view_another_scholarship
      puts "\nWould you like to view more funding options?"
      puts prompt.colorize(:light_blue)
      input = gets.strip.downcase
      if input == "y"
        show_scholarship_list
        select_scholarship
        view_another_scholarship
      elsif input == "n"
        view_events_after_scholarships
      else
        puts error.colorize(:light_blue)
        view_another_scholarship
      end
    end
    
   def view_events_after_scholarships
      puts "\nWould you like to view an event?"
      puts prompt.colorize(:light_blue)
      input = gets.strip.downcase
      if input == "y"
        reset_events
        event_sequence
      elsif input == "n"
        puts goodbye.colorize(:light_blue)
        exit
      else
        puts error.colorize(:light_blue)
        view_events_after_scholarships
      end
    end
    
    def reset_events
      Event.reset_all
    end
  
  end
  
  module ClassMethods
  end

end